
package cluedo;

import java.io.Serializable;

import cluedo.info.*;


/**
 * Information exchange between clients and server is carried out by
 * transmitting instances of this class via TCP.  E.g. if a client wants
 * to get a list of all available sessions from the server it creates an
 * instance of SessionListRequestinfo.  Instead of transmitting the info
 * object directly to the server it is "wrapped" into an instance of
 * CluedoPDU.  The PDU is transmitted to the server.  Beside from  the
 * Info object the PDU contains two more fields: The field
 * {@link #senderId senderId} (see
 * {@link cluedo.info.PlayerAddRequestInfo PlayerAddRequestInfo})
 * itdentifies the sending client.  The {@link #priority priority} informs
 * about the level of importance of the transported information.  The
 * protocol design of the interactive Cluedo game supports two
 * priotrity levels (0 and 1).  Packets of priority 0 must be transmitted.
 * Packets of priority 1 are transmitted only if the packet queue of the
 * sender is below a certain level, i.e. does not contain more than 10
 * packets to be transmitted.
 *
 * <p><strong>Design goal:</strong>  The distinction between PDU and Info
 * objects allows us to design the communication between client and server
 * independent from the transport protocol.  Info objects can be
 * interpreted as the "language" talked by client and server while
 * PDU objects can be interpreted as the way of communication.  This way
 * it is possible to change the transport protocol without modifying the
 * program logic of the application.</p>
 *
 * @author  PI4
 * @version $Id: CluedoPDU.java,v 1.1.1.1 2001/05/14 07:47:15 gk Exp $
 * @see     cluedo.CluedoPDU
 */
public class CluedoPDU implements Serializable
{
    public static final int VERSION= 1;
    // Attribute



    protected int    version= VERSION;

    /**
     * Who sends this PDU?  The senderid is the same unique id used by
     * many inheritors of CluedoInfo to identify a certain player
     * (playerId).  The unique number is created by the server and
     * transmitted to a client when it connects to the server (see
     * {@link cluedo.info.PlayerAddRequestInfo PlayerAddRequestInfo}).
     */
    protected int    senderId;

    /**
     * The priority of the PDU.  The protocol design of the interactive
     * Cluedo game supports two priotrity levels (0 and 1).  Packets of
     * priority 0 must be transmitted.  Packets of priority 1 are
     * transmitted only if the packet queue of the sender is below a
     * certain level, i.e. does not contain more than 10 packets to be
     * transmitted. (see {@link #cluedoInfo cluedoInfo})
     */
    protected int    priority;

    /**
     * The intrinsic information that is to be transported between client
     * and server.
     */
    protected CluedoInfo cluedoInfo;

    // Methoden:
    // ---------

    /** This constructor sets the priority to zero (0) */
    public CluedoPDU(int senderId, CluedoInfo cluedoInfo)
    // {{{ body
    {
	this.senderId   = senderId;
	this.priority   = 0;
	this.cluedoInfo = cluedoInfo;
    }
    // }}}

    public CluedoPDU(int senderId, int priority, CluedoInfo cluedoInfo)
    // {{{ body
    {
	this.senderId   = senderId;
	this.priority   = priority;
	this.cluedoInfo = cluedoInfo;
    }
    // }}}

    /**
     * Get the {@link #senderId senderId}.
     */
    public int        getSenderId()
    { return senderId; }

    /**
     * Set the {@link #senderId senderId}.
     */
    public void       setSenderId(int senderId)
    { this.senderId= senderId; }

    /**
     * Get the {@link #priority priority}.
     */
    public int        getPriority()
    { return priority; }

    /**
     * Set the {@link #priority priority}.
     */
    public void       setPriority(int priority)
    { this.priority= priority; }

    /**
     * Get the {@link #cluedoInfo cluedoInfo} object.
     */
    public CluedoInfo getCluedoInfo()
    { return cluedoInfo; }

    /**
     * Get the {@link #cluedoInfo cluedoInfo} object.
     */
    public void       setCluedoInfo(CluedoInfo cluedoInfo)
    { this.cluedoInfo= cluedoInfo; }

    /**
     * Get the {@link #version version}.
     */
    public int       getVersion()
    { return this.version; }

}

